
@BOTTOM@

/* */
#undef VERSION

/* */
#undef HAVE_TYPEOF

/* */
#undef HAVE_LONG_LONG

/* */
#undef HAVE_POINTER_COMPARISON_BUG

/* */
#undef HAVE_MAXINT_CONVERSION_BUG

/* */
#undef HAVE_SOCKLEN_T

/* */
#undef C_BIG_ENDIAN

/* */
#undef C_LITTLE_ENDIAN

/* */
#undef RENAME_OVER_EXISTING_FILES

/* */
#undef HAVE_STRLEN

/* */
#undef HAVE_STRCPY

/* */
#undef HAVE_STRCHR

/* */
#undef HAVE_STRRCHR

/* */
#undef HAVE_STRCMP

/* */
#undef HAVE_STRNCMP

/* */
#undef HAVE_STRCSPN

/* */
#undef HAVE_STRSTR

/* */
#undef HAVE_MEMMOVE

/* */
#undef HAVE_STRERROR

/* */
#undef HAVE_SIGSETJMP

/* */
#undef HAVE_GETHOSTBYNAME

/* */
#undef HAVE_GETHOSTBYNAME_BUG

/* */
#undef DEBUGLEVEL

/* */
#undef JS

/* */
#undef CHCEME_FLEXI_LIBU

/* */
#undef HAVE_PCRE

/* */
#undef HAVE_REGEX

/* */
#undef ENABLE_UTF8

/* */
#undef HAVE_BEGINTHREAD

/* */
#undef HAVE_PTHREADS

/* */
#undef X2

/* */
#undef HAVE_SSL

/* */
#undef HAVE_OPENSSL

/* */
#undef HAVE_NSS

/* */
#undef HAVE_ZLIB

/* */
#undef HAVE_BZIP2

/* */
#undef G

/* */
#undef GRDRV_SVGALIB

/* */
#undef GRDRV_FB

/* */
#undef GRDRV_DIRECTFB

/* */
#undef GRDRV_X

/* */
#undef GRDRV_SDL

/* */
#undef GRDRV_PMSHELL

/* */
#undef GRDRV_ATHEOS

/* */
#undef DONT_INCLUDE_SETJMP

/* Jpeg by Clock */
#undef HAVE_JPEG

/* Tiff by Brain */
#undef HAVE_TIFF
